##############################################################################
# $Id: tabpanel.tcl,v 1.5 1998/09/16 04:27:31 stewart Exp $
#
# tabpanel.tcl - procedures to implement a tabpanel widget
#
# Copyright (C) 1996-1998 Stewart Allen
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

##############################################################################
#

proc vTcl:tabpanel {args} {
    global vTcl
    set widget [lindex $args 0]
    set cmd [lindex $args 1]
    set name [lindex $args 2]
    set usesb [lindex $args 3]

	if {$usesb == ""} { set usesb 0 }

    if {[llength $args] == 1} {
        frame $widget
        frame $widget.l
        canvas $widget.c -width 10 -height 25

		if {$usesb} {
			$widget.c conf -xscrollcommand "$widget.sh set"
			$widget.c conf -yscrollcommand "$widget.sv set"
			scrollbar $widget.sh -orient horiz -command "$widget.c xview"
			scrollbar $widget.sv -orient vert -command "$widget.c yview"
		}

        grid $widget.l -sticky news -columnspan 2
		if {$usesb} {
			grid $widget.c $widget.sv -sticky news
			grid $widget.sh -sticky news
		} else {
			grid $widget.c -sticky news
		}

        grid columnconf $widget 0 -weight 1
        grid rowconf $widget 1 -weight 1
        update idletasks
        bind $widget <Configure> "vTcl:tabpanel_update $widget"

		label $widget.l.__rightpad -border 1 -relief raised \
			-bg white -text "<<< tool selection <<<" -anchor center
		pack $widget.l.__rightpad -side right -expand 1 -fill x

        set vTcl(tab,$widget,current) ""
		proc tab$widget {args} "
			eval vTcl:tabpanel $widget \$args
		"
        return tab$widget
    }

	set vTcl(tab,$widget,usesb) $usesb

	set frame_name [vTcl:tb_frame_name $widget $name]
	set label_name [vTcl:tb_label_name $widget $name]

    switch $cmd {
        addtab {
            set name [vTcl:rename $name]
			set vTcl(tab,$widget,name) $name
			set vTcl(tab,$name) $widget

            label $label_name -text $name -bd 1 -relief raised -width 10 -anchor center
            bind $label_name <ButtonPress> "vTcl:tabpanel_raise $widget $name"
            pack $label_name -side left -expand 0

            frame $frame_name
            bind $frame_name <Configure> "
                vTcl:tabpanel_update $widget
            "
            $widget.c create window 0 0 -window $frame_name -tag $name -anchor nw

            vTcl:tabpanel_raise $widget $name
            return $frame_name
        }
		select {
			vTcl:tabpanel_raise $widget $name
		}
		hastab {
			set ex [winfo exists $frame_name]
			return $ex
		}
		gettab {
			return $frame_name
		}
		getwidget {
			return $widget
		}
    }
}

proc vTcl:tb_frame_name {widget name} {
	return $widget.c._$name
}

proc vTcl:tb_label_name {widget name} {
	return $widget.l._$name
}

proc vTcl:tabpanel_raise {widget name} {
    global vTcl

	set frame_name [vTcl:tb_frame_name $widget $name]
	set label_name [vTcl:tb_label_name $widget $name]
    set c $vTcl(tab,$widget,current)

    if {$c != ""} {
		# move the widget way off the screen
        $widget.c coords $c -1000 -1000
        [vTcl:tb_label_name $widget $c] conf -bg lightgray
    }

	# move the widget back into the visible world
    $widget.c coords $name 0 0
    $label_name conf -bg gray

	vTcl:tabpanel_update $widget

    set vTcl(tab,$widget,current) $name
}

proc vTcl:tabpanel_update {widget} {
    global vTcl

    update idletasks
    set name $vTcl(tab,$widget,current)
	set frame_name [vTcl:tb_frame_name $widget $name]

	if {$name == ""} { return }
    set cw [winfo width $widget.c]
    set ch [winfo height $widget.c]
    set fw [winfo width $frame_name]
    set fh [winfo height $frame_name]

	if {$vTcl(tab,$widget,usesb)} {
		if {$cw < $fw} {
			grid $widget.sh -sticky news -column 0 -row 2
		} else {
			grid forget $widget.sh
		}
		if {$ch < $fh} {
			grid $widget.sv -sticky news -column 1 -row 1
		} else {
			grid forget $widget.sv
		}
		$widget.c conf -scrollregion "0 0 $fw $fh"
	} else {
		$widget.c itemconf $name -width $cw -height $ch
	}
}

proc vTcl:tabtest {} {
    source misc.tcl
    set p [vTcl:tabpanel .x]
    set a [$p addtab "test"]
    text $a.t
    pack $a.t
    set b [$p addtab "fred"]
    label $b.l -text "this is a label"
    button $b.b -text "this is a button" -command "
        text $b.t
        pack $b.t
    "
    pack $b.l $b.b

    pack .x -expand 1 -fill both

	$p select "test"
}

#vTcl:tabtest
