##############################################################################
# $Id: tops.tcl,v 1.12 1998/09/16 04:27:31 stewart Exp $
#
# tops.tcl - procedures for managing toplevel windows
#
# Copyright (C) 1996-1998 Stewart Allen
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

##############################################################################
#

proc vTcl:wm_take_focus {target} {
    global vTcl
    if {$vTcl(w,class) == "Toplevel"} {
        set vTcl(w,insert) $target
    }
    vTcl:place_handles $vTcl(w,widget)
}

proc vTcl:destroy_top {target} {
    global vTcl
    if [winfo exists $target] {
        if {[vTcl:get_class $target] == "Toplevel"} {
            destroy $target
        }
    }
    if {[info procs window($target] != ""} {
        rename window($target {}
    }
    if {[info procs window((pre)$target] != ""} {
        rename window($target {}
    }
    if {[info procs window((post)$target] != ""} {
        rename window($target {}
    }
    set x [lsearch $vTcl(tops) $target]
    if {$x >= 0} {
        set vTcl(tops) [lreplace $vTcl(tops) $x $x]
    }
}

proc vTcl:show_top {target} {
    global vTcl
    if [winfo exists $target] {
        if {[vTcl:get_class $target] == "Toplevel"} {
            wm deiconify $target
            raise $target
        }
    } else {
        Window show $target
        wm deiconify $target
        raise $target
        vTcl:setup_bind_tree $target
        vTcl:update_top_list
    }
}

proc vTcl:hide_top {target} {
    global vTcl
    if [winfo exists $target] {
        if {[vTcl:get_class $target] == "Toplevel"} {
            wm withdraw $target
        }
    }
}

proc vTcl:update_top_list {} {
    global vTcl

	set base [vTcl:prop:get_tab_frame tops]
	$base.f2.list delete 0 end
	set index 0
	foreach i $vTcl(tops) {
		if [catch {set n [wm title $i]}] {
			set n $i
		}
		$base.f2.list insert end $n
		set vTcl(tops,$index) $i
		incr index
	}
}

proc vTcl:tops:create_list {base} {
    global vTcl

    frame $base.frame7 \
        -borderwidth 1 -height 30 -relief sunken -width 30 
    pack $base.frame7 \
        -anchor center -expand 0 -fill x -ipadx 0 -ipady 0 \
        -padx 0 -pady 0 -side bottom 
    button $base.frame7.button8 \
        -command {
			set base [vTcl:prop:get_tab_frame tops]
            set vTcl(x) [$base.f2.list curselection]
            if {$vTcl(x) != ""} {
                vTcl:show_top $vTcl(tops,$vTcl(x))
            }
        } \
         -padx 9 \
        -pady 3 -text Show -width 4 
    pack $base.frame7.button8 \
        -anchor center -expand 1 -fill x -ipadx 0 \
        -ipady 0 -padx 0 -pady 0 -side left 
    button $base.frame7.button9 \
        -command {
			set base [vTcl:prop:get_tab_frame tops]
            set vTcl(x) [$base.f2.list curselection]
            if {$vTcl(x) != ""} {
                vTcl:hide_top $vTcl(tops,$vTcl(x))
            }
        } \
         -padx 9 \
        -pady 3 -text Hide -width 4 
    pack $base.frame7.button9 \
        -anchor center -expand 1 -fill x -ipadx 0 \
        -ipady 0 -padx 0 -pady 0 -side left 
    button $base.frame7.button10 \
        -command {
			set base [vTcl:prop:get_tab_frame tops]
            set vTcl(x) [$base.f2.list curselection]
            if {$vTcl(x) != ""} {
                vTcl:destroy_top $vTcl(tops,$vTcl(x))
                $base.f2.list delete $vTcl(x)
            }
        } \
         -padx 9 \
        -pady 3 -text Delete -width 4
    pack $base.frame7.button10 \
        -anchor center -expand 1 -fill x -ipadx 0 \
        -ipady 0 -padx 0 -pady 0 -side left 
    frame $base.f2 \
        -borderwidth 1 -height 30 -relief sunken -width 30 
    pack $base.f2 \
        -anchor center -expand 1 -fill both -ipadx 0 \
        -ipady 0 -padx 0 -pady 0 -side top 
    listbox $base.f2.list \
        -yscrollcommand "$base.f2.sb4 set" -exportselection 0
    bind $base.f2.list <Double-Button-1> {
		set base [vTcl:prop:get_tab_frame tops]
        set vTcl(x) [$base.f2.list curselection]
        if {$vTcl(x) != ""} {
            vTcl:show_top $vTcl(tops,$vTcl(x))
        }
    }
    pack $base.f2.list \
        -anchor center -expand 1 -fill both -ipadx 0 \
        -ipady 0 -padx 0 -pady 0 -side left 
    scrollbar $base.f2.sb4 \
        -command "$base.f2.list yview"
    pack $base.f2.sb4 \
        -anchor center -expand 0 -fill y -ipadx 0 \
        -ipady 0 -padx 0 -pady 0 -side right 
}

